unit ProfileForm_Unit;

interface

uses
  Windows, Messages, SysUtils, Variants, Classes, Graphics, Controls, Forms,
  Dialogs, StdCtrls, ExtCtrls;

type
  TProfileForm = class(TForm)
    Panel1: TPanel;
    ProfileListBox: TListBox;
    ProfileEdit: TEdit;
    LoadButton: TButton;
    CreateButton: TButton;
    DeleteButton: TButton;
    CancelButton: TButton;
    procedure CancelButtonClick(Sender: TObject);
    procedure FormShow(Sender: TObject);
    procedure ProfileListBoxClick(Sender: TObject);
    procedure ProfileEditChange(Sender: TObject);
    procedure CreateButtonClick(Sender: TObject);
    procedure DeleteButtonClick(Sender: TObject);
    procedure LoadButtonClick(Sender: TObject);
    procedure ProfileListBoxDblClick(Sender: TObject);
    procedure FormClose(Sender: TObject; var Action: TCloseAction);
  private
    { Private-Deklarationen }
  public
    { Public-Deklarationen }
  end;

procedure UpdateProfiles;

var
  ProfileForm: TProfileForm;

implementation

uses MainForm_Unit;

{$R *.dfm}

procedure UpdateProfiles;
var Search: TSearchRec;
begin
  with ProfileForm do begin
    ProfileListBox.Clear;
    ProfileEdit.Clear;
    if DirectoryExists(HomeDir + '\PROFILES') then
      begin
        SetCurrentDir(HomeDir + '\PROFILES');
        if FindFirst('*.ini', faAnyFile, Search) = 0 then
          begin
            repeat
              ProfileListBox.Enabled := TRUE;
              ProfileListBox.Items.Add(Copy(Search.Name, 1, Length(Search.Name)-4));
            until FindNext(Search) <> 0;
          end;
      end;
    if ProfileListBox.Items.Count = 0 then
    begin
      ProfileListBox.Items.Add('No profiles found...');
      ProfileListBox.Enabled := FALSE;
    end;
  end;
end;

procedure TProfileForm.CancelButtonClick(Sender: TObject);
begin
  Close();
end;

procedure TProfileForm.FormShow(Sender: TObject);
begin
  UpdateProfiles;
end;

procedure TProfileForm.ProfileListBoxClick(Sender: TObject);
begin
  ProfileEdit.Text := ProfileListBox.Items[ProfileListBox.ItemIndex];
end;

procedure TProfileForm.ProfileEditChange(Sender: TObject);
begin
  if Length(ProfileEdit.Text) > 0 then begin
    CreateButton.Enabled := TRUE;
    LoadButton.Enabled := TRUE;
    DeleteButton.Enabled := TRUE;
  end else begin
    CreateButton.Enabled := FALSE;
    LoadButton.Enabled := FALSE;
    DeleteButton.Enabled := FALSE;
  end;
end;

procedure TProfileForm.CreateButtonClick(Sender: TObject);
var i: Integer;
    tmp: TextFile;
begin
  if not DirectoryExists(HomeDir + '\PROFILES\') then MkDir(HomeDir + '\PROFILES\');
  for i := 0 to ProfileListBox.Items.Count-1 do
    if AnsiLowerCase(ProfileListBox.Items[i]) = AnsiLowerCase(ProfileEdit.Text) then
      if MessageBox(0, 'The Profile already exists. Do you want to overwrite it?', 'Profile exists', MB_ICONQUESTION or MB_YESNO) = IDNO then Exit;
  AssignFile(tmp, HomeDir + '\PROFILES\' + ProfileEdit.Text + '.ini');
  ReWrite(tmp);
  CloseFile(tmp);
  Profile := ProfileEdit.Text;
  MainForm.StatusBar.Panels[0].Text := 'Profile: ' + Profile;
  Close();
end;

procedure TProfileForm.DeleteButtonClick(Sender: TObject);
begin
  if FileExists(HomeDir + '\PROFILES\' + ProfileEdit.Text + '.ini') then
  begin
    DeleteFile(HomeDir + '\PROFILES\' + ProfileEdit.Text + '.ini');
    UpdateProfiles;
    Profile := '';
    MainForm.StatusBar.Panels[0].Text := 'Profile: [none]';
  end else MessageBox(0, 'The Profile does not exist.', 'Error', MB_ICONERROR or MB_OK);
end;

procedure TProfileForm.LoadButtonClick(Sender: TObject);
begin
  Profile := ProfileEdit.Text;
  MainForm.StatusBar.Panels[0].Text := 'Profile: ' + Profile;
  Close();
end;

procedure TProfileForm.ProfileListBoxDblClick(Sender: TObject);
begin
  LoadButton.Click;
end;

procedure TProfileForm.FormClose(Sender: TObject;
  var Action: TCloseAction);
begin
  with MainForm do
    if Profile = '' then
    begin
      Options1.Enabled := FALSE;
      MainForm.OnlineButton.Enabled := FALSE;
    end else
    begin
      Options1.Enabled := TRUE;
      MainForm.OnlineButton.Enabled := TRUE;
    end;
end;

end.
